@@ -104,12 +104,10 @@ class DataCollection:
 
         if first_data_el is not None:
             yield ",".join(
-                first_data_el[column] if first_data_el[column] is not None else ""
-                for column in columns_to_store
+                first_data_el.get(column) or "" for column in columns_to_store
             ) + "\n"
 
         for data_el in self:
             yield ",".join(
-                data_el[column] if data_el[column] is not None else ""
-                for column in columns_to_store
+                data_el.get(column) or "" for column in columns_to_store
             ) + "\n"
